# DisJotter

DisJotter allows the user to interactively create a Docker image from a Jupyter Notebook.

# DisJotter

DisJotter allows the user to interactively create a Docker image from a Jupyter Notebook.

